@@ -10,10 +10,10 @@
 #ifndef MOBIPOCKET_H
 #define MOBIPOCKET_H
 
-#include <QtCore/QString>
-#include <QtCore/QByteArray>
-#include <QtCore/QMap>
-#include <QtGui/QImage>
+#include <QString>
+#include <QByteArray>
+#include <QMap>
+#include <QImage>
 
 #include "qmobipocket_export.h"
 
